@@ -65,14 +65,14 @@ test_that("auk_ebd prints method", {
   expect_output(print(ebd), "Complete checklists only: no")
 
   # now fake apply filters
-  filters <- ebd %>%
-    auk_species(species = c("Canada Jay", "Blue Jay")) %>%
-    auk_country(country = c("US", "Canada")) %>%
-    auk_bbox(bbox = c(-100, 37, -80, 52)) %>%
-    auk_date(date = c("2012-01-01", "2012-12-31")) %>%
-    auk_last_edited(date = c("2010-01-01", "2017-12-31")) %>%
-    auk_time(start_time = c("06:00", "09:00")) %>%
-    auk_duration(duration = c(0, 60)) %>%
+  filters <- ebd |>
+    auk_species(species = c("Canada Jay", "Blue Jay")) |>
+    auk_country(country = c("US", "Canada")) |>
+    auk_bbox(bbox = c(-100, 37, -80, 52)) |>
+    auk_date(date = c("2012-01-01", "2012-12-31")) |>
+    auk_last_edited(date = c("2010-01-01", "2017-12-31")) |>
+    auk_time(start_time = c("06:00", "09:00")) |>
+    auk_duration(duration = c(0, 60)) |>
     auk_complete()
   filters$output <- "output.txt"
   filters$output_sampling <- "output_sampling.txt"
